@@ -239,7 +239,8 @@ col_plan_span_structure_to_vars <- function(x, column_names, data_names, presele
 char_as_quo <- function(x) {
 
   is_negative <- grepl("^-", x)
-  x <- gsub("^-", "", x)
+  x <- gsub("^-", "", x) # Removes the leading '-'
+  x <- gsub("^`|`$", "", x) # Removes leading/trailing backticks for col names with spaces in
 
   ## if x is a valid tidyselect call, leave it as is,
   ## otherwise wrap it in "`". This is so we can pass
